@@ -122,7 +122,7 @@ pcadapt.pcadapt_pool <- function(input,
                                  LD.clumping = NULL,
                                  pca.only = FALSE) {
   
-  w <- matrix(NA, nrow = ncol(input), ncol = K)
+  w <- matrix(NA_real_, nrow = ncol(input), ncol = K)
   
   tmat <- scale(input, center = TRUE, scale = FALSE) 
   tmat[is.na(tmat)] <- 0 # mean imputation
@@ -133,23 +133,25 @@ pcadapt.pcadapt_pool <- function(input,
   pass <- mean_freq > min.maf
   
   if (nrow(input) == 2) {
-    obj.pca <- list()
-    obj.pca$u <- matrix(0, nrow = 1, ncol = 2)
-    obj.pca$v <- tmat[1, pass, drop = FALSE]
-    obj.pca$d <- 1
+    obj.pca <- list(
+      u = matrix(NA_real_, nrow = 2, ncol = 1),
+      v = t(tmat[1, pass, drop = FALSE]),
+      d = 1
+    )
   } else {
-    obj.pca <- RSpectra::svds(tmat[, pass, drop = FALSE], k = K)
+    obj.pca <- svd(tmat[, pass, drop = FALSE])
+    #obj.pca <- RSpectra::svds(tmat[, pass, drop = FALSE], k = K)
   }
   
-  w[pass, ] <- obj.pca$v 
+  w[pass, ] <- obj.pca$v[, 1:K, drop = FALSE]
   res <- get_statistics(w, 
                         method = method, 
                         pass = pass)
-  
+
   structure(
     list(
-      scores = obj.pca$u,
-      singular.values = sqrt(obj.pca$d * nrow(w) / (nrow(obj.pca$u) - 1)),
+      scores = obj.pca$u[, 1:K, drop = FALSE],
+      singular.values = sqrt(obj.pca$d[1:K]^2 / sum(obj.pca$d^2)) ,
       loadings = w,
       zscores = w,
       af = attr(tmat, "scaled:center"),
@@ -158,7 +160,7 @@ pcadapt.pcadapt_pool <- function(input,
       stat = res$stat,
       gif = res$gif,
       pvalues = res$pvalues,
-      pass = pass
+      pass = which(pass)
     ),
     K = K, method = method, min.maf = min.maf, class = "pcadapt"
   )
@@ -242,7 +244,7 @@ pcadapt0 <- function(input, K, method, min.maf, ploidy, LD.clumping, pca.only) {
   structure(
     list(
       scores = obj.pca$u,
-      singular.values = sqrt(obj.pca$d * nrow(obj.pca$v) / (nrow(obj.pca$u) - 1)),
+      singular.values = obj.pca$d / sqrt((nrow(obj.pca$u) - 1) * length(obj.pca$pass)),
       loadings = obj.pca$v,
       zscores = obj.pca$zscores,
       af = obj.pca$af,
@@ -273,4 +275,4 @@ run.pcadapt <- function() {
   shiny::runApp(appDir, launch.browser = TRUE)
 }
 
-################################################################################
\ No newline at end of file
+################################################################################
